Trait Input
Source pub trait Input {
type Data;
type Ack;
// Required method
fn run(self) -> Result<(), Error>;
}
A trait for a data source that produces messages of type Data.
Fetches events and send them as Data. It also receives and processes
Ack, which acknowledges the receipt of a certain Data.
Errors
Returns an error if it fails to fetch events, or receives an invalid
Data or Ack.